
import java.util.HashMap;
import java.util.Map;

import javax.jms.Connection;
import javax.jms.ConnectionFactory;
import javax.jms.MessageConsumer;
import javax.jms.MessageProducer;
import javax.jms.Queue;
import javax.jms.Session;
import javax.jms.TextMessage;

import org.hornetq.api.core.TransportConfiguration;
import org.hornetq.api.jms.HornetQJMSClient;
import org.hornetq.api.jms.JMSFactoryType;
import org.hornetq.core.remoting.impl.netty.NettyConnectorFactory;
import org.hornetq.core.remoting.impl.netty.TransportConstants;

import org.hornetq.api.core.DiscoveryGroupConfiguration;
import org.hornetq.api.core.client.loadbalance.RandomStickyConnectionLoadBalancingPolicy;
import org.hornetq.jms.client.HornetQConnectionFactory;


public class QueuePull
{
    public static void main(String[] args) throws Exception
    {
        String server_host = args[0];
        long max_count = Integer.parseInt(args[1]);

        Map connectionParams = new HashMap();
        connectionParams.put(TransportConstants.HOST_PROP_NAME, server_host);
        connectionParams.put(TransportConstants.PORT_PROP_NAME, 5445);
        TransportConfiguration transportConfiguration = 
                new TransportConfiguration(NettyConnectorFactory.class.getName(),connectionParams);
        ConnectionFactory cf = (ConnectionFactory) HornetQJMSClient.createConnectionFactoryWithoutHA(JMSFactoryType.CF,transportConfiguration);

        Queue exampleQueue = HornetQJMSClient.createQueue("exampleQueue");
        Connection connection = cf.createConnection();

        Session session = connection.createSession(false, Session.AUTO_ACKNOWLEDGE);
        MessageConsumer consumer = session.createConsumer(exampleQueue);

        connection.start();

        long start = java.lang.System.currentTimeMillis();
        long restart = start;
        long count = 0;
        try {
            while ( count < max_count )
            {
                TextMessage receivedMessage = (TextMessage)consumer.receive();
                ++count;
                if ( count % 1000 == 0 )
                {
                    long now = java.lang.System.currentTimeMillis();
                    System.out.println("R #" + count + " : 1000 in " + (now - restart) + "ms" );
                    restart = now;
                }
            }
        } finally {
            if (session != null)
            {
                session.close();
            }
            if (connection != null)
            {
                connection.close();
            }
        }
        System.out.println("End run: " + count + " read in " + (java.lang.System.currentTimeMillis() - start) + "ms" );

    }
}


